==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/ArmPlacementPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.mojang.serialization.Codec;
import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;
import com.zurrtum.create.content.kinetics.mechanicalArm.ArmBlockEntity;
import com.zurrtum.create.content.kinetics.mechanicalArm.ArmInteractionPoint;
import java.util.List;
import net.minecraft.class_2338;
import net.minecraft.class_2499;
import net.minecraft.class_2596;
import net.minecraft.class_2792;
import net.minecraft.class_3244;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record ArmPlacementPacket(class_2499 tag, class_2338 pos) implements class_2596<class_2792> {
    public static final class_9139<class_9129, ArmPlacementPacket> CODEC = class_9139.method_56435(
        CatnipStreamCodecs.COMPOUND_LIST_TAG,
        ArmPlacementPacket::tag,
        class_2338.field_48404,
        ArmPlacementPacket::pos,
        ArmPlacementPacket::new
    );

    public ArmPlacementPacket(List<ArmInteractionPoint> points, class_2338 pos) {
        this(new class_2499(), pos);
        Codec<ArmInteractionPoint> codec = ArmInteractionPoint.getCodec(null, pos);
        ArmBlockEntity.appendEncodedPoints(points, codec, this.tag);
    }

    @Override
    public void handle(class_2792 listener) {
        AllHandle.onArmPlacement((class_3244) listener, this);
    }

    @Override
    public class_9145<ArmPlacementPacket> method_65080() {
        return AllPackets.PLACE_ARM;
    }
}

==> create-fly-6.0.7-1.21.8-19-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/ArmPlacementPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.mojang.serialization.Codec;
import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;
import com.zurrtum.create.content.kinetics.mechanicalArm.ArmBlockEntity;
import com.zurrtum.create.content.kinetics.mechanicalArm.ArmInteractionPoint;
import java.util.List;
import java.util.function.BiConsumer;
import net.minecraft.class_2338;
import net.minecraft.class_2499;
import net.minecraft.class_3244;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record ArmPlacementPacket(class_2499 tag, class_2338 pos) implements C2SPacket {
    public static final class_9139<class_9129, ArmPlacementPacket> CODEC = class_9139.method_56435(
        CatnipStreamCodecs.COMPOUND_LIST_TAG,
        ArmPlacementPacket::tag,
        class_2338.field_48404,
        ArmPlacementPacket::pos,
        ArmPlacementPacket::new
    );

    public ArmPlacementPacket(List<ArmInteractionPoint> points, class_2338 pos) {
        this(new class_2499(), pos);
        Codec<ArmInteractionPoint> codec = ArmInteractionPoint.getCodec(null, pos);
        ArmBlockEntity.appendEncodedPoints(points, codec, this.tag);
    }

    @Override
    public boolean runInMain() {
        return true;
    }

    @Override
    public class_9145<ArmPlacementPacket> method_65080() {
        return AllPackets.PLACE_ARM;
    }

    @Override
    public BiConsumer<class_3244, ArmPlacementPacket> callback() {
        return AllHandle::onArmPlacement;
    }
}
